@@ -122,7 +122,9 @@ class AegisHandler(tornado.web.RequestHandler):
             if hasattr(self, '_member_auth'):
                 self._member_auth.refresh(options.cookie_durations['auth'] * 86400)
             # Update auth cookie as long as it isn't being overwritten
-            new_cookie_value = self._new_cookie.get(self.cookie_name('auth'))
+            new_cookie_value = None
+            if hasattr(self, "_new_cookie"):
+                new_cookie_value = self._new_cookie.get(self.cookie_name('auth'))
             if not new_cookie_value:
                 self.cookie_set('auth', auth_ck)
             else:
@@ -238,6 +240,7 @@ class AegisHandler(tornado.web.RequestHandler):
 
     def _handle_request_exception(self, ex):
         if type(ex) in (aegis.database.PgsqlAdminShutdown, aegis.database.PgsqlOperationalError, aegis.database.MysqlOperationalError, aegis.database.MysqlInterfaceError):
+            logging.exception(ex)
             logging.error("Database is down. Send HTTP 503.")
             self.send_error(503)
             return
@@ -255,6 +258,10 @@ class AegisHandler(tornado.web.RequestHandler):
         # Send errors to chat hooks, based on them being configured for the environment
         header = "`[%s ENV   %s   %s   uid: %s   mid: %s]`" % (config.get_env().upper(), self.request.uri, self.tmpl['request_name'], self.get_user_id() or '-', self.get_member_id() or '-')
         template_opts = {'handler': self, 'traceback': traceback.format_exc(), 'kwargs': {}, 'header': header}
+        template_opts['kwargs']['user_agent'] = self.tmpl['user_agent']
+        template_opts['kwargs']['remote_ip'] = self.request.remote_ip
+        template_opts['kwargs']['robot'] = self.user_is_robot()
+        template_opts['kwargs']['Python UTC Now'] = self.tmpl['utcnow'].strftime('%Y-%m-%dT%H:%M:%S')
         error_message = self.render_string("error_message.txt", **template_opts).decode('utf-8')
         if config.get_env() == 'prod':
             hooks = ['alerts_chat_hook']
@@ -520,6 +527,7 @@ class AegisHandler(tornado.web.RequestHandler):
             self.cookie_set('session', self.tmpl['session_ck'])
         # Audit Request
         url_parts = urllib.parse.urlparse(self.request.uri)
+        self.audit_session['audit_session_id'] = audit_session_id
         self.audit_request['audit_session_id'] = audit_session_id
         self.audit_request['request_name'] = self.tmpl['request_name']
         self.audit_request['url_path_tx'] = url_parts.path
